rnalysis.filtering.Pipeline
===========================

.. currentmodule:: rnalysis.filtering

.. autoclass:: Pipeline

   
   
   
    .. automethod:: __init__
    
    

   
.. autosummary::
    :toctree: .
    
    Pipeline.add_function
    Pipeline.apply_to
    Pipeline.remove_last_function
    
    